QC: Quality control

Description Usage Arguments Value

Description

Function performing a quality control on...

Usage

1
2
QC(geno, pheno, MkMiss = 0.1, GenMiss = 0.1, MAFlim = 0.05,
  pheno_imp = "mean", geno_imp = "random")

Arguments

geno

Genotype marker score matrix in HapMap format.

pheno

Data.frame with the first column being character genotype identifier and the next column being numeric phenotypic values.

MAFlim

Critical minor allele frequency under which markers are removed. Default = 0.05.

pheno_imp

Method for imputation of the missing phenotypic values. One of : 'no', 'random', 'mean'. Default = 'mean'.

geno_imp

Method for imputation of the missing marker scores values. For the moment only 'random'.

Mkmiss

Maximum percentage of phenotypic values in the markers. Default = 0.1.

#' @param Genmiss Maximum percentage of phenotypic values in the genotypes. Default = 0.1.

Value

Return:

List with two objects

gp

a gpData object containing all data processed data (genotype, map, phenotype) that can directly be used in the function GWAS_scan()

genoHapMap

The sorted genotype marker matrix in HapMap format that can be used for GWAS analysis in TASSEL using the function GWAS_TASSEL().


vincentgarin/GWASToolBox documentation built on May 6, 2019, 8:59 p.m.