QC_GenotypingError: Detect genotyping errors

Description Usage Arguments Value Author(s) Examples

Description

Check if markers have more than two alleles.

Usage

1
QC_GenotypingError(mk.mat, parallel = FALSE, cluster = NULL)

Arguments

mk.mat

Character marker scores matrix with genotypes as row and markers as column. Rows and columns names must be the genotype and marker identifiers respectively. Marker scores must be coded using one letter per allele. For example, AA, CC, GG, TT, AC, AG, AT, CA, CG, CT, GA, GC, GT, TA, TC, TG. Missing values must be coded NA.

parallel

Logical value specifying if the function should be executed in parallel on multiple cores. Default = FALSE.

cluster

Cluster object obtained with the function makeCluster() from the parallel package. Default = NULL.

Value

Return:

prob.mk

Character vector containing the name of marker with more than two alleles.

Author(s)

Vincent Garin

Examples

1
Come later

vincentgarin/GWASToolBox documentation built on May 6, 2019, 8:59 p.m.