QC_missing: Missing value for marker or genotype

Description Usage Arguments Value Author(s) Examples

Description

Identify markers or genotypes with a missing rate higher than the specified threshold.

Usage

1
QC_missing(mk.mat, threshold = 0.1, MARGIN = 2)

Arguments

mk.mat

Character marker score matrix with genotype as row and marker as column. Rows and columns names must be the genotype and marker identifiers respectively. Missing values must be coded NA.

threshold

Numeric value representing the missing values rate above which a marker or a genotype is considered as problematic. Default = 0.1.

MARGIN

Numeric value giving the subscript which the function will be applied over. If MARGIN = 1, the function looks at the genotypes (rows). If MARGIN = 2, the function looks at the markers (columns). Default = 2.

Value

Return:

mis.ind

Three columns data.frame with: 1) marker or genotype names; 2) column or row positions in the matrix; and 3) The percentages of missing values.

Author(s)

Vincent Garin

Examples

1
2
3
4
5
6
7
data('USNAM_geno')

# missingness of markers
QC_missing(mk.mat = USNAM_geno)

# missingness of genotypes
QC_missing(mk.mat = USNAM_geno, threshold = 0.2, MARGIN = 1)

vincentgarin/GWASToolBox documentation built on May 6, 2019, 8:59 p.m.